==> image_effects-8.x-1.1.tar.gz: image_effects/src/Plugin/ImageToolkit/Operation/imagemagick/ReplaceImage.php <==
<?php

namespace Drupal\image_effects\Plugin\ImageToolkit\Operation\imagemagick;

use Drupal\imagemagick\Plugin\ImageToolkit\Operation\imagemagick\ImagemagickImageToolkitOperationBase;
use Drupal\image_effects\Plugin\ImageToolkit\Operation\ReplaceImageTrait;

/**
 * Defines Imagemagick image replace operation.
 *
 * @ImageToolkitOperation(
 *   id = "image_effects_imagemagick_replace_image",
 *   toolkit = "imagemagick",
 *   operation = "replace_image",
 *   label = @Translation("Replace image"),
 *   description = @Translation("Replace the current image with another one.")
 * )
 */
class ReplaceImage extends ImagemagickImageToolkitOperationBase {

  use ReplaceImageTrait;

  /**
   * {@inheritdoc}
   */
  protected function execute(array $arguments) {
    $replacement = $arguments['replacement_image'];

    // Replacement image local path.
    $local_path = $replacement->getToolkit()->getSourceLocalPath();
    if ($local_path === '') {
      $source_path = $replacement->getToolkit()->getSource();
      throw new \InvalidArgumentException("Missing local path for image at {$source_path}");
    }

    $this->getToolkit()
      ->resetArguments()
      ->setSourceLocalPath($replacement->getToolkit()->getSourceLocalPath())
      ->setSourceFormat($replacement->getToolkit()->getSourceFormat())
      ->setExifOrientation($replacement->getToolkit()->getExifOrientation())
      ->setWidth($replacement->getWidth())
      ->setHeight($replacement->getHeight());
    return TRUE;
  }

}

==> image_effects-8.x-3.5.tar.gz: image_effects/src/Plugin/ImageToolkit/Operation/imagemagick/ReplaceImage.php <==
<?php

namespace Drupal\image_effects\Plugin\ImageToolkit\Operation\imagemagick;

use Drupal\image_effects\Plugin\ImageToolkit\Operation\ReplaceImageTrait;
use Drupal\imagemagick\Plugin\ImageToolkit\Operation\imagemagick\ImagemagickImageToolkitOperationBase;

/**
 * Defines Imagemagick image replace operation.
 *
 * @ImageToolkitOperation(
 *   id = "image_effects_imagemagick_replace_image",
 *   toolkit = "imagemagick",
 *   operation = "replace_image",
 *   label = @Translation("Replace image"),
 *   description = @Translation("Replace the current image with another one.")
 * )
 */
class ReplaceImage extends ImagemagickImageToolkitOperationBase {

  use ReplaceImageTrait;

  /**
   * {@inheritdoc}
   */
  protected function execute(array $arguments) {
    $replacement = $arguments['replacement_image'];

    // Replacement image local path.
    $local_path = $replacement->getToolkit()->ensureSourceLocalPath();
    if ($local_path === '') {
      $source_path = $replacement->getToolkit()->getSource();
      throw new \InvalidArgumentException("Missing local path for image at {$source_path}");
    }

    $this->getToolkit()->arguments()
      ->reset()
      ->setSourceLocalPath($replacement->getToolkit()->ensureSourceLocalPath())
      ->setSourceFormat($replacement->getToolkit()->arguments()->getSourceFormat());
    $this->getToolkit()
      ->setWidth($replacement->getWidth())
      ->setHeight($replacement->getHeight())
      ->setExifOrientation($replacement->getToolkit()->getExifOrientation())
      ->setColorspace($replacement->getToolkit()->getColorspace())
      ->setProfiles($replacement->getToolkit()->getProfiles())
      ->setFrames($replacement->getToolkit()->getFrames());

    return TRUE;
  }

}
